from typing import Any

from numpy.polynomial import (
    chebyshev as chebyshev,
    hermite as hermite,
    hermite_e as hermite_e,
    laguerre as laguerre,
    legendre as legendre,
    polynomial as polynomial,
)

Polynomial: Any
Chebyshev: Any
Legendre: Any
Hermite: Any
HermiteE: Any
Laguerre: Any
set_default_printstyle: Any
